# sql_pylib

<!-- #region -->

## Install docquity_pylib package

`pip install sql_pylib`

### Create a text file containing credentials for RedShift
* Create a `creds.txt` file
* Copy paste your credentials in this format:

```
NAME_DB=sample-redshift
HOST_DB=sample-redshift-prod.....ap-southeast-1.redshift.amazonaws.com
PORT_DB=5XXX
USER_DB=XXXX
PASSWORD_DB=XXXX
```

* Note that you must copy the credentials as-is. Do not add quotation marks

## Compatibility
Right now, this works on Redshift Postgresql, and may work on MySQL (not tested)

## Sample usage
More examples how to use can be found in [Sample Usage](https://github.com/PrinceJavier/sql_pylib/blob/main/docs/01_sql_builder_functions.ipynb)

### Import and define SQLBuilder
```python
from sql_pylib.sql_builder import SQLBuilder 
DOTENV_FILE = "./creds.txt"
sql = SQLBuilder(credentials=DOTENV_FILE, sql_type='postgresql') # or sql_type='mysql'
```

### Show table in database
```python
q = sql.get_table_names(schema="schema_name")
df = sql.download(q)
```

### Show columns in a table
```python
q = sql.get_column_names(table_name="table_name", schema="schema_name")
df = sql.download(q)
```

### Run any Query/Instruction on Redshift Cluster (without needing to download)
```python
q = "SELECT 123"
sql.run_query(q)
```

#### Download Query as Pandas DataFrame
```python
q = """SELECT 123 AS test_col """
df = sql.download_query(q)
```

### Quickly download from a table (automatically gets all columns)
#### Get all columns if columns not specified
```python
q = sql.make_query(schema='schema_name',
                   table_name='table_name', 
                   filters="id BETWEEN 0 AND 5000",
                   limit=5)
df = sql.download(q.query)
```

#### Select only certain columns
```python
q = sql.make_query(schema='schema_name',
                   table_name='table_name',
                   cols=['id AS user_id', 'user_name'])
q = q.limit(5) # limit can also be defined here
df = sql.download(q.query)
```

### Building queries using SQL Builder
##### Query with conditions
```python
cols = "col1, col2, col1 + col2 AS col3"
cols = ['col1', 'col2', 'col1 + col2 AS col3']

table1 = "user_table"
table2 = "item_table"
conditions = "col1 > col2 AND col1 > 0"

q = (SQLBuilder()
     .select(cols)
     .from_table(table1)
     .where(conditions))

# print corresponding SQL query
print(q.query)
```
<!-- #endregion -->