import pandas as pd
import psycopg2 # needed to connect to redshift for postgres
import pymysql # for MYSQL
import sqlalchemy
from sqlalchemy.pool import StaticPool
import pandas.io.sql as sqlio # for reading SQL then saving to pandas

def load_from_redshift_to_pandas(query, credentials, sql_type='postgresql'):
    """
    Load data from RedShift warehouse to Pandas dataframe using a SQL query
    Prereq: pandas, psycopg2
    
    Input:
        query (str) - SQL query string, e.g. SELECT * FROM table LIMIT 5
        credentials (dict) - dictionary of RedShift credentials in the form:
            {'dbname': '...',
             'host': '...',
             'port': '...',
             'user': '...',
             'password': '...'}
        sql_type (str) - default='postgresql', altern ative:'mysql'
    Returns:
        df (dataframe) - Pandas dataframe of the table
    """
    
    if sql_type == 'postgresql':
        # connect to redshift database
        conn=psycopg2.connect(**credentials)  
        # use sql alchemy as stated by the warning
        engine=sqlalchemy.create_engine('postgresql+psycopg2://', poolclass=StaticPool, creator = lambda: conn)        
        # load dataframe
        df = pd.read_sql_query(sqlalchemy.text(query), con=engine)         
        
    elif sql_type == 'mysql':
        conn=pymysql.connect(**credentials)          
        # load dataframe
        df = sqlio.read_sql_query(query, conn)   
    
    # close connections
    conn.close() # close the connection    
    
    return df
